package sgc.portal.cs.cspop.persistence;

import org.apache.ibatis.annotations.Mapper;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cs.cspop.model.CSPOPVo;
import sgc.portal.cs.cspop.model.CSTcsSiteTradeChrgrVo;
import sgc.portal.cs.cspop.dto.CSPOPSearch;

import java.util.List;

@Mapper
public interface CSPOPMapper {
	
	List<EasyHashMap<String, Object>> getSiteList(CSPOPSearch search);
	
	List<EasyHashMap<String, Object>> getSiteAllList(CSPOPSearch search);
	
	List<EasyHashMap<String, Object>> getProdList(CSPOPSearch search);
	
	List<EasyHashMap<String, Object>> getVendList(CSPOPSearch search);
	
	List<EasyHashMap<String, Object>> getSmsList(CSPOPSearch search);
	
	List<EasyHashMap<String, Object>> getEmpPopLst(CSPOPSearch search);
	
	int insertSms(CSPOPVo cSPOPVo);
	
	
	List<EasyHashMap<String, Object>> selectGuarIntuNmList(CSPOPSearch search);
	List<EasyHashMap<String, Object>> selectSiteCovendList(CSPOPSearch search);
	List<EasyHashMap<String, Object>> selectTcsSiteTradeItemPopList(CSPOPSearch search);
	List<EasyHashMap<String, Object>> selectCovendPopList(CSPOPSearch search);
	
	EasyHashMap<String, Object> selectCommonPopSmComCovendList(CSPOPSearch search);
	List<EasyHashMap<String, Object>> selectCommonPopTcsSiteTradeList(CSPOPSearch search);
	List<EasyHashMap<String, Object>> selectCommonPopTcsSiteTradeGuarList(CSPOPSearch search);
	List<EasyHashMap<String, Object>> selectCommonPopSmComCovendChrgrList(CSPOPSearch search);
	void updateSmComCovendChrgrPop(CSTcsSiteTradeChrgrVo cSTcsSiteTradeChrgrVo);
	void insertSmComCovendChrgrPop(CSTcsSiteTradeChrgrVo cSTcsSiteTradeChrgrVo);
	int selectSmComCovendAS1(CSPOPSearch search);
	int selectSmComCovendAS2(CSPOPSearch search);
	int selectSmComCovendAS3(CSPOPSearch search);
}
